surname

# XMLRésuméLibrary: User Guide

suffix | Element Reference | tail

## Name

surname — A family name

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `surname` element contains a person's family, or last name.

### Parents

`surname` may be contained in these elements: `name`

## Examples

For examples, see `name`.

suffix | Element Reference | tail